@@ -483,6 +483,14 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
           writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.DOOR_OR_WINDOW_WALL_DISTANCE, i, 
               doorOrWindow.getWallDistance() * doorOrWindow.getDepth());
         }
+        if (!doorOrWindow.isWallCutOutOnBothSides()) {
+          writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.DOOR_OR_WINDOW_WALL_CUT_OUT_ON_BOTH_SIDES, i, 
+              doorOrWindow.isWallCutOutOnBothSides());
+        }
+        if (!doorOrWindow.isWidthDepthDeformable()) {
+          writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.DOOR_OR_WINDOW_WIDTH_DEPTH_DEFORMABLE, i, 
+              doorOrWindow.isWidthDepthDeformable());
+        }
         Sash [] sashes = doorOrWindow.getSashes();
         if (sashes.length > 0) {
           String sashXAxis = "";
@@ -563,6 +571,9 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
       if (piece.getStaircaseCutOutShape() != null) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.STAIRCASE_CUT_OUT_SHAPE, i, piece.getStaircaseCutOutShape());
       }
+      if (piece.getModelSize() != null) {
+        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.MODEL_SIZE, i, piece.getModelSize());
+      }
       if (!piece.isResizable()) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.RESIZABLE, i, piece.isResizable());
       }
@@ -572,6 +583,9 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
       if (!piece.isTexturable()) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.TEXTURABLE, i, piece.isTexturable());
       }
+      if (!piece.isHorizontallyRotatable()) {
+        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.HORIZONTALLY_ROTATABLE, i, piece.isHorizontallyRotatable());
+      }
       writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.PRICE, i, piece.getPrice());
       writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.VALUE_ADDED_TAX_PERCENTAGE, i, piece.getValueAddedTaxPercentage());
       writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.CURRENCY, i, piece.getCurrency());
